import type { ShikiInstance } from './types';
declare global {
    var __nuxt_shiki__: ShikiInstance | Promise<ShikiInstance>;
}
/**
 * Lazy-load shiki instance.
 *
 * You can use this utility both in `server/` and vue app code.
 *
 * @example
 * ```vue
 * <script setup>
 * const shiki = await loadShiki()
 * const html = shiki.highlight(`const hello = 'shiki'`, { lang: 'js' })
 * </script>
 * ```
 *
 * @example
 * ```ts
 * // server/api/highlight.ts
 * export default defineEventHandler(async (event) => {
 *   const shiki = await loadShiki()
 *   return shiki.highlight(`const hello = 'shiki'`, { lang: 'js' })
 * })
 * ```
 */
export declare function loadShiki(): Promise<ShikiInstance>;
