import { ref, watchEffect, watch, toRef } from "vue";
import { loadShiki } from "./loadShiki.mjs";
export async function useHighlighted(code, options = {}) {
  const _code = toRef(code);
  if ("themes" in options && !options.themes) {
    delete options.themes;
  }
  if (import.meta.server) {
    const shiki = await loadShiki();
    return ref(shiki.highlight(_code.value, options));
  }
  const highlighted = ref(options.highlighted || "");
  if (highlighted.value) {
    const unwatch = watch(_code, () => {
      unwatch();
      init();
    });
  } else {
    await init();
  }
  function init() {
    loadShiki().then((shiki) => {
      watchEffect(() => {
        highlighted.value = shiki.highlight(_code.value, options);
      });
    });
  }
  return highlighted;
}
